==> butler-blocks-1.1.0.tgz: package/lib/documentLabeler/MockDocumentLabelerProvider.stories.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx } from "react/jsx-runtime";
import { useReducer } from 'react';
import { DocumentLabelerDispatchContext, DocumentLabelerStateContext } from './DocumentLabelerProvider';
import { MockDocumentLabelerData } from './MockDocumentLabelerData.stories';
import { documentLabelerReducer } from './state/DocumentLabelerReducer';
import { DocumentLabelerState } from './state/DocumentLabelerState';
/**
 * Takes in an internal state of the Document Labeler Provider to allow for
 * testing of internal components with particular state configurations.
 */
export var MockDocumentLabelerProvider = function (_a) {
    var children = _a.children, internalState = _a.internalState;
    var _b = useReducer(documentLabelerReducer, internalState === undefined
        ? DocumentLabelerState.generateInitialState(MockDocumentLabelerData.documentLabelerData, null)
        : internalState), state = _b[0], dispatch = _b[1];
    return (_jsx(DocumentLabelerStateContext.Provider, __assign({ value: state }, { children: _jsx(DocumentLabelerDispatchContext.Provider, __assign({ value: dispatch }, { children: children })) })));
};

==> butler-blocks-1.1.2.tgz: package/lib/documentLabeler/MockDocumentLabelerProvider.stories.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx } from "react/jsx-runtime";
import { useReducer } from 'react';
import { DocumentLabelerDispatchContext, DocumentLabelerStateContext, } from './DocumentLabelerProvider';
import { MockDocumentLabelerData } from './MockDocumentLabelerData.stories';
import { documentLabelerReducer } from './state/DocumentLabelerReducer';
import { DocumentLabelerState, } from './state/DocumentLabelerState';
/**
 * Takes in an internal state of the Document Labeler Provider to allow for
 * testing of internal components with particular state configurations.
 */
export var MockDocumentLabelerProvider = function (_a) {
    var children = _a.children, internalState = _a.internalState;
    var _b = useReducer(documentLabelerReducer, internalState === undefined
        ? DocumentLabelerState.generateInitialState(MockDocumentLabelerData.documentLabelerData, null)
        : internalState), state = _b[0], dispatch = _b[1];
    return (_jsx(DocumentLabelerStateContext.Provider, __assign({ value: state }, { children: _jsx(DocumentLabelerDispatchContext.Provider, __assign({ value: dispatch }, { children: children })) })));
};
